#
# spec file for package gearlever
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define appid it.mijorus.gearlever
Name:           gearlever
Version:        2.0.7
Release:        bp160.1.6
Summary:        Manage AppImages
License:        GPL-3.0-or-later
URL:            https://gearlever.mijorus.it/
Source:         https://github.com/mijorus/gearlever/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM: https://github.com/mijorus/gearlever/pull/80
Group:          System/X11/Utilities
BuildArch:      noarch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  gtk4-tools
BuildRequires:  meson
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(gio-2.0)
Requires:       flatpak-spawn
Requires:       p7zip
Requires:       python3-dbus-python
Requires:       python3-pyxdg

%description
An utility to manage AppImages with ease! Gear lever will organize and manage
AppImage files for you, generate desktop entries and app metadata, update apps
in-place or keep multiple versions side-by-side.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %name --all-name
%suse_update_desktop_file %{appid}
%fdupes %{buildroot}/%{_prefix}
rm %{buildroot}/%{_datadir}/gearlever/gearlever/assets/demo.AppImage

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/appdata/%{appid}.appdata.xml
%{_datadir}/applications/%{appid}.desktop
%{_datadir}/glib-2.0/schemas/%{appid}.gschema.xml
%{_datadir}/icons/hicolor/scalable/actions
%{_datadir}/icons/hicolor/*/apps/%{appid}*.svg

%files lang -f %{name}.lang

%changelog
* Mon Sep 23 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 2.0.7:
  * Fixed incorrect url detection for some links
- Update to 2.0.6:
  * Updated appimage type detection according to the specs
  * Moved the "Cancel download" button to avoid unintentional errors
- Update to 2.0.5:
  * Added checks to detect if Gear Lever is running as a flatpak
  * Bug fix
* Sat Aug  3 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 2.0.4
  * Improved checking for static update url
  * Do not append md5 hashes to filenames anymore
- Update to 2.0.3
  * Added support for apps that do not specify icons in their desktop file
- Update to 2.0.1
  * Accept globe characters in the release names of custom Github update links
  * Fixed an issue causing crashes on systems that do not support gtk-launch
  * Fixed an issue causing crashes when attempting to open apps with non-ascii characters in their names
  * Fixed an issue causing some appimages to be considered invalid because of the lack of an AppRun file
- Update to 2.0.0
  * Gear Lever can now fetch updates from embedded or custom sources and update your apps automaticallyo
- Update to 1.6.5
  * Improved support for NixOS
- Update to 1.6.4
  * Fixed an issue causing the app to crash if the "strings" util is not available
- Update to 1.6.3
  * Keep environment variables when updating an app with the "Replace" option
  * Fixed an issue causing app to override themself when updating with "Keep" option
- Update to 1.6.2
  * Fixed bugs introduced with 1.6.1 causing the app to crash at startup
  * Fixed an issue causing multi-install to fail
- Update to 1.6.1
  * Added Appimage Type 3 detection
  * Added error warning when libfuse is missing on the host system
* Tue Jun  4 2024 Rodrigo Pedra Brum <rodrigo.pedra@gmail.com>
- Update to 1.6.0
  * Improved app analysis performance
  * Improved debug logs
  * Fixed some issues with special characters in filenames
- Drop 0001-Rename-icon-with-generic-name-that-conflicts-with-an.patch
* Fri May 10 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add 0001-Rename-icon-with-generic-name-that-conflicts-with-an.patch
* Tue May  7 2024 Rodrigo Pedra Brum <rodrigo.pedra@gmail.com>
- Update to 1.5.2
* Mon Dec 11 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 1.0.18
- Drop 0001-Don-t-install-the-file-gearlever.in.patch
* Mon Dec  4 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add 0001-Don-t-install-the-file-gearlever.in.patch
* Wed Nov 22 2023 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Initial package
